sievetools.ResidueClass
=======================

.. inheritance-diagram:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass
   :private-bases:

.. autoclass:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.modulo

.. autoattribute:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.residue

Methods
-------

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.get_boolean_train

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.get_congruent_bases

Special Methods
---------------

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__and__

   .. note:: Inherited from :py:class:`sievetools._BaseResidueClass <abjad.tools.sievetools._BaseResidueClass._BaseResidueClass._BaseResidueClass>`

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__eq__

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__ge__

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__gt__

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__le__

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__lt__

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__ne__

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__or__

   .. note:: Inherited from :py:class:`sievetools._BaseResidueClass <abjad.tools.sievetools._BaseResidueClass._BaseResidueClass._BaseResidueClass>`

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__repr__

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__str__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__xor__

   .. note:: Inherited from :py:class:`sievetools._BaseResidueClass <abjad.tools.sievetools._BaseResidueClass._BaseResidueClass._BaseResidueClass>`
